import React, { useState } from "react";
import Loading from "../../util/loading.component";
import PlayerNameInput from "./player-name-input.component";
import JoinGameInput from "./join-game-input.component";
import { createGame, joinGame } from "../../../services/ggsh.service";

// TODO set round timer for new game

const NewGame = ({ onCreateGame, cannotCreateGame }) => (
  <button className="btn new-game__btn" onClick={onCreateGame} disabled={cannotCreateGame}>
    Create New Game
  </button>
);

const PreGame = ({ initPlayerName, onGameJoined }) => {
  const [loading, setLoading] = useState(false);
  const [gameId, setGameId] = useState(null);
  const [playerName, setPlayerName] = useState(initPlayerName);

  if (loading) {
    return <Loading/>
  }

  const onChangePlayerName = ({ target }) => setPlayerName(target.value);
  const onChangeGameId = ({ target }) => setGameId(target.value.trim());
  const onCreateGame = async () => {
    setLoading(true);
    const gameId = await createGame(playerName, 300);
    onGameJoined({ gameId, playerName });
  };
  const cannotCreateGame = !playerName || playerName.length === 0;
  const onJoinGame = async () => {
    // TODO would like to support re-joining a game you left
    setLoading(true);
    await joinGame(gameId, playerName);
    onGameJoined({ gameId, playerName });
  };
  const cannotJoinGame = cannotCreateGame || !gameId || gameId.length === 0;

  return (
    <div className="new-game">
      <PlayerNameInput {...{ playerName, onChangePlayerName }} />
      <hr/>
      <NewGame {...{ onCreateGame, cannotCreateGame }} />
      <hr/>
      <JoinGameInput {...{ gameId, onChangeGameId, onJoinGame, cannotJoinGame }} />
    </div>
  );
}

export default PreGame;
